@@ -137,7 +137,7 @@ def create(id):
         toolkit.get_action("package_revise")(None, revise_package_dict)
     # unlikely to happen, but just to demonstrate error handling
     except (ValidationError):
-        return base.abort(404, _(u'Dataset not found'))
+        return base.abort(404, _(u'Dataset not ssssfound'))
     # redirect tp dataset read page
     return toolkit.redirect_to('dataset.read',
                                id=id)
